@@ -1,8 +1,10 @@
 """Storage Connectors for CloudWanderer."""
 from .base_connector import BaseStorageConnector
 from .dynamodb import DynamoDbConnector
+from .memory import MemoryStorageConnector
 
 __all__ = [
     'DynamoDbConnector',
+    'MemoryStorageConnector',
     'BaseStorageConnector'
 ]
